@@ -22,6 +22,12 @@ class PlaceAMS(Place):
     street_name: Optional[str] = None
     street_nr: Optional[str] = None
     street_type: Optional[str] = None
+    street_type_suffix: Optional[str] = None
+    street_type_prefix: Optional[str] = None
+    street_number_prefix: Optional[str] = None
+    street_number_suffix: Optional[str] = None
+    dir_prefix: Optional[str] = None
+    dir_suffix: Optional[str] = None
     floor: Optional[str] = None
     unit: Optional[str] = None
     address_type: Optional[str] = None
